%define version 10.0.5
%define rel 5
%define prerel %{nil}

%if "%{prerel}" != "%{nil}"
%define lc_prerel %(echo %{prerel} | tr "A-Z" "a-z")
%define release %mkrel 1.%{lc_prerel}.%{rel}
%else
%define release %mkrel %{rel}
%endif

# exclude 3rd party library from dependencies scanning
%global __requires_exclude_from ^%{_datadir}/%{name}/3rdparty/
%global __provides_exclude_from ^%{_datadir}/%{name}/3rdparty/
# exclude remaining PHP dependencies as long as their usage is not proven
%global __requires_exclude pear\\(.*\\)
%define __jar_repack %{nil}

Summary:      Open personal cloud
Name:         nextcloud
Version:      %{version}
Release:      %{release}
Source0:      https://download.nextcloud.com/server/releases/%{name}-%{version}%{?prerel}.zip
License:      AGPLv3
Group:        Monitoring
Url:          http://nextcloud.com
Requires:     apache-mod_php
Requires:     php-zip
Requires:     php-mbstring
Requires:     php-gd
Requires:     php-curl
Requires:     php-iconv
Requires:     php-opcache 
Recommends:   php-sqlite3 php-pdo_sqlite php-fileinfo
BuildArch:    noarch

Obsoletes:    owncloud  < 9.1.50
Provides:     owncloud = %version-%release

%description
A personal cloud server which runs on you personal server 
and enables accessing your data from everywhere and sharing 
with other people.

%prep
%setup -q -n %{name}

%install
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -pr * %{buildroot}%{_datadir}/%{name}

rm -rf %{buildroot}%{_datadir}/%{name}/config
rm -f %{buildroot}%{_datadir}/%{name}/AUTHORS
rm -f %{buildroot}%{_datadir}/%{name}/COPYING-AGPL
rm -f %{buildroot}/.htaccess

ca_bundle=%{buildroot}%{_datadir}/%{name}/resources/config/ca-bundle.crt
rm -f $ca_bundle
ln -s ../../../../../etc/pki/tls/certs/ca-bundle.crt $ca_bundle

mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}
pushd %{buildroot}%{_datadir}/%{name}
ln -s ../../..%{_sysconfdir}/%{name} config
ln -s ../../..%{_localstatedir}/lib/%{name} data
popd

# make config and apps directory apache-writable
chmod 775 %{buildroot}%{_sysconfdir}/%{name}
chmod 775 %{buildroot}%{_datadir}/%{name}/apps

mkdir -p %{buildroot}%{webappconfdir}
cat > %{buildroot}%{webappconfdir}/%{name}.conf <<EOF
# %{name} configuration
Alias /%{name} %{_datadir}/%{name}

<Directory %{_datadir}/%{name}>
    <IfModule mod_authz_core.c>
        # Apache 2.4
        Require all granted
    </IfModule>
    <IfModule !mod_authz_core.c>
        # Apache 2.2
        Order allow,deny
        Allow from all
    </IfModule>

    AddDefaultCharset utf-8
    php_value upload_max_filesize 513M
    php_value post_max_size 513M
    php_value memory_limit 512M
    php_value mbstring.func_overload 0
    php_value always_populate_raw_post_data -1

    <IfModule mod_fcgid.c>
        <IfModule mod_setenvif.c>
            <IfModule mod_headers.c>
                SetEnvIfNoCase ^Authorization$ "(.+)" XAUTHORIZATION=$1
                RequestHeader set XAuthorization %{XAUTHORIZATION}e env=XAUTHORIZATION
            </IfModule>
        </IfModule>
    </IfModule>

    <IfModule mod_rewrite.c>
        RewriteEngine on
        RewriteBase /nextcloud
        RewriteRule .* - [env=HTTP_AUTHORIZATION:%{HTTP:Authorization}]
        RewriteRule ^\.well-known/host-meta public.php?service=host-meta [QSA,L]
        RewriteRule ^\.well-known/host-meta\.json public.php?service=host-meta-json [QSA,L]
        RewriteRule ^\.well-known/carddav remote.php/carddav/ [R]
        RewriteRule ^\.well-known/caldav remote.php/caldav/ [R]
        RewriteRule ^apps/calendar/caldav\.php remote.php/caldav/ [QSA,L]
        RewriteRule ^apps/contacts/carddav\.php remote.php/carddav/ [QSA,L]
        RewriteRule ^remote/(.*) remote.php [QSA,L]
    </IfModule>
</Directory>

<Directory %{_datadir}/%{name}/data>
    <IfModule mod_authz_core.c>
        # Apache 2.4
        Require all denied
    </IfModule>
    <IfModule !mod_authz_core.c>
        # Apache 2.2
        Order Deny,Allow
        Deny from All
        Allow from None
    </IfModule>
</Directory>
EOF

cat > %{buildroot}%_datadir/%name/.htaccess <<EOF
# Version: %{version}
EOF

pushd %buildroot%{webappconfdir}
	ln -s %name.conf owncloud.conf
popd


%post
if [ -e %{_localstatedir}/lib/owncloud/config.php -a ! -e %{_localstatedir}/lib/%name/config.php ]; then
    mv %{_localstatedir}/lib/owncloud/config.php %{_localstatedir}/lib/%name/
fi

# Upgrade from Owncloud 9.1.5 : we move the config file as it is now in nextcloud conf directory
if [ -e %{_sysconfdir}/owncloud/config.php ]; then
    mv %{_sysconfdir}/owncloud/config.php %{_sysconfdir}/%name/config.php
    # if the default path was not changed, we move it to nextcloud
    sed -i s+http://localhost/owncloud+http://localhost/nextcloud+  %{_sysconfdir}/%name/config.php
    # if the default data path was not changed, the link has disappeared so we point to the real folder
    sed -i s+/usr/share/owncloud/data+/var/lib/owncloud+  %{_sysconfdir}/%name/config.php
fi

%files
%doc AUTHORS
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/3rdparty
%{_datadir}/%{name}/core
%{_datadir}/%{name}/config
%{_datadir}/%{name}/data
%{_datadir}/%{name}/lib
%{_datadir}/%{name}/l10n
%{_datadir}/%{name}/occ
%{_datadir}/%{name}/ocs
%{_datadir}/%{name}/ocs-provider
%{_datadir}/%{name}/resources
%{_datadir}/%{name}/settings
%{_datadir}/%{name}/themes
%{_datadir}/%{name}/updater
%{_datadir}/%{name}/*.php
%{_datadir}/%{name}/db_structure.xml
%{_datadir}/%{name}/index.html
%{_datadir}/%{name}/robots.txt
%{_datadir}/%{name}/.htaccess
%attr(-,root,apache) %{_datadir}/%{name}/apps
%attr(-,root,apache) %{_sysconfdir}/%{name}
%attr(-,apache,apache) %{_localstatedir}/lib/%{name}
%config(noreplace) %{webappconfdir}/*.conf


%changelog
* Mon Jul 10 2017 zezinho <zezinho> 10.0.5-5.mga5
+ Revision: 1109627
- better fix default data path change when coming from owncloud
- fix default data path change when coming from owncloud
- change default path from owncloud to next cloud if the config is still default one
- move owncloud conf file to nextcloud
- backported version 10 to allow upgrade to MGA6 MGA#21066
- copy for backport

* Tue May 16 2017 luigiwalser <luigiwalser> 11.0.3-1.mga6
+ Revision: 1102246
- 11.0.3

* Sun Mar 05 2017 neoclust <neoclust> 11.0.2-1.mga6
+ Revision: 1088905
- New version 11.0.2

* Sun Jan 01 2017 luigiwalser <luigiwalser> 10.0.2-1.mga6
+ Revision: 1078936
- 10.0.2

* Sun Dec 11 2016 ngompa <ngompa> 10.0.1-3.mga6
+ Revision: 1074254
- Remove unneeded %%pretrans

* Mon Oct 24 2016 neoclust <neoclust> 10.0.1-2.mga6
+ Revision: 1063374
- Requires php-opcache

* Wed Oct 12 2016 zezinho <zezinho> 10.0.1-1.mga6
+ Revision: 1060534
- new version now in tar.bz2

* Tue Sep 13 2016 neoclust <neoclust> 10.0.0-1.mga6
+ Revision: 1052529
- New version 10.0.0

* Wed Aug 10 2016 neoclust <neoclust> 9.0.53-1.mga6
+ Revision: 1045479
- Add owncloud.conf for compatibility
- New version 9.0.53

* Mon Jul 04 2016 neoclust <neoclust> 9.0.50-2.mga6
+ Revision: 1038684
- Fix nextcloud URL

* Sun Jun 19 2016 neoclust <neoclust> 9.0.50-1.mga6
+ Revision: 1036847
- imported package nextcloud

